@@ -37,7 +37,8 @@ public:
         REF_CLK_CALIBRATION,
         TRIG_IO_MODE,
         GPIO_POWER,
-        SPI_GETTER_IFACE
+        SPI_GETTER_IFACE,
+        INTERNAL_SYNC
     };
 
     virtual ~discoverable_feature() = default;
