@@ -38,6 +38,7 @@ static const std::string ACTION_KEY_STREAM_CMD("stream_cmd");
 static const std::string ACTION_KEY_RX_EVENT("rx_event");
 static const std::string ACTION_KEY_RX_RESTART_REQ("restart_request");
 static const std::string ACTION_KEY_TX_EVENT("tx_event");
+static const std::string ACTION_KEY_TUNE_REQUEST("tune_request");
 
 //! If the block name can't be automatically detected, this name is used
 static const std::string DEFAULT_BLOCK_NAME = "Block";
@@ -76,7 +77,8 @@ static const device_type_t X400 = 0xA400;
 static const noc_id_t ADDSUB_BLOCK         = 0xADD00000;
 static const noc_id_t DUC_BLOCK            = 0xD0C00000;
 static const noc_id_t DDC_BLOCK            = 0xDDC00000;
-static const noc_id_t FFT_BLOCK            = 0xFF700000;
+static const noc_id_t FFT_BLOCK_V1         = 0xFF700000;
+static const noc_id_t FFT_BLOCK_V2         = 0xFF700002;
 static const noc_id_t FIR_FILTER_BLOCK     = 0xF1120000;
 static const noc_id_t FIR_FILTER_BLOCK_V2  = 0xF1120002;
 static const noc_id_t FOSPHOR_BLOCK        = 0x666F0000;
