@@ -12,9 +12,9 @@
 #include <uhd/utils/log.hpp>
 
 //! helper macro for safe call to produce warnings
-#define _UHD_SAFE_CALL_WARNING(code, what)                                           \
-    UHD_LOGGER_ERROR("UHD") << UHD_THROW_SITE_INFO("Exception caught in safe-call.") \
-                                   + #code + " -> " + what;
+#define _UHD_SAFE_CALL_WARNING(code, what)                                             \
+    UHD_LOGGER_WARNING("UHD") << UHD_THROW_SITE_INFO("Exception caught in safe-call.") \
+                                     + #code + " -> " + what;
 
 /*!
  * A safe-call catches all exceptions thrown by code,
