@@ -10,24 +10,47 @@
 #include <uhd/rfnoc/multichan_register_iface.hpp>
 #include <uhd/rfnoc/property.hpp>
 #include <uhd/rfnoc/registry.hpp>
+#include <uhdlib/utils/compat_check.hpp>
 
 using namespace uhd::rfnoc;
 
+// Block compatability version
+const uint16_t fir_filter_block_control::MAJOR_COMPAT = 1;
+const uint16_t fir_filter_block_control::MINOR_COMPAT = 1;
+
+// Register offsets
 const uint32_t fir_filter_block_control::REG_FIR_BLOCK_SIZE           = 1 << 4;
 const uint32_t fir_filter_block_control::REG_FIR_MAX_NUM_COEFFS_ADDR  = 0x00;
 const uint32_t fir_filter_block_control::REG_FIR_LOAD_COEFF_ADDR      = 0x04;
 const uint32_t fir_filter_block_control::REG_FIR_LOAD_COEFF_LAST_ADDR = 0x08;
+// This register is available starting at compat version 1.1
+const uint32_t fir_filter_block_control::REG_COMPAT_NUM_ADDR = 0x0C;
 
 // User property names
 const char* const PROP_KEY_MAX_NUM_COEFFS = "max_num_coeffs";
 
+namespace {
+constexpr uhd::compat_num32 MIN_VERSION_LOAD_BACKWARDS{1, 1};
+}
+
 class fir_filter_block_control_impl : public fir_filter_block_control
 {
 public:
     RFNOC_BLOCK_CONSTRUCTOR(fir_filter_block_control),
-        _fir_filter_reg_iface(*this, 0, REG_FIR_BLOCK_SIZE)
+        _fir_filter_reg_iface(*this, 0, REG_FIR_BLOCK_SIZE),
+        _compat(get_noc_id() == FIR_FILTER_BLOCK
+                    ? uhd::compat_num32(1, 0)
+                    : uhd::compat_num32(regs().peek32(REG_COMPAT_NUM_ADDR))),
+        _coeff_load_backwards(_compat >= MIN_VERSION_LOAD_BACKWARDS)
     {
         UHD_ASSERT_THROW(get_num_input_ports() == get_num_output_ports());
+        RFNOC_LOG_DEBUG("Compat version: " << _compat.to_string());
+        if (_compat.get_major() > MAJOR_COMPAT) {
+            UHD_LOG_THROW(uhd::runtime_error,
+                get_unique_id(),
+                "Compat version on FPGA is ahead of known maximum compat version ("
+                    << MAJOR_COMPAT << ")");
+        }
         _register_props();
     }
 
@@ -134,27 +157,39 @@ private:
 
     void _program_coefficients(const size_t chan = 0)
     {
-        // Write coefficients [0..num_coeffs-2]...
-        const size_t num_coeffs = _coeffs.at(chan).size();
-        std::vector<uint32_t> coeffs_addr(num_coeffs - 1, REG_FIR_LOAD_COEFF_ADDR);
+        // Creat local reference to coefficients
+        auto& coeffs            = _coeffs.at(chan);
+        const size_t num_coeffs = coeffs.size();
+
+        // Write coefficients. The order depends on _coeff_load_backwards.
+        const std::vector<uint32_t> coeffs_addr(num_coeffs - 1, REG_FIR_LOAD_COEFF_ADDR);
+        // Here we store all coefficients except the last one (which goes to a
+        // different address), converted to 32-bits for easy poking.
         std::vector<uint32_t> coeffs_minus_last(num_coeffs - 1);
-        std::transform(_coeffs.at(chan).begin(),
-            _coeffs.at(chan).end() - 1,
-            coeffs_minus_last.begin(),
-            [](int16_t value) -> uint32_t { return static_cast<uint32_t>(value); });
+
+        const auto last_coeff = _coeff_load_backwards ? coeffs.front() : coeffs.back();
+        if (_coeff_load_backwards) {
+            std::transform(coeffs.rbegin(),
+                coeffs.rend() - 1,
+                coeffs_minus_last.begin(),
+                [](int16_t value) -> uint32_t { return static_cast<uint32_t>(value); });
+        } else {
+            std::transform(coeffs.begin(),
+                coeffs.end() - 1,
+                coeffs_minus_last.begin(),
+                [](int16_t value) -> uint32_t { return static_cast<uint32_t>(value); });
+        }
 
         _fir_filter_reg_iface.multi_poke32(coeffs_addr, coeffs_minus_last, chan);
         // ...and the final coefficient (num_coeffs-1)
-        _fir_filter_reg_iface.poke32(REG_FIR_LOAD_COEFF_LAST_ADDR,
-            static_cast<uint32_t>(_coeffs.at(chan).at(num_coeffs - 1)),
-            chan);
+        _fir_filter_reg_iface.poke32(
+            REG_FIR_LOAD_COEFF_LAST_ADDR, static_cast<uint32_t>(last_coeff), chan);
     }
 
-    //! Maximum number of coefficients supported by the FIR filter
-    std::vector<size_t> _max_num_coeffs;
-
-    //! Current fir filter coefficients
-    std::vector<std::vector<int16_t>> _coeffs;
+    /**************************************************************************
+     * Register interface
+     *************************************************************************/
+    multichan_register_iface _fir_filter_reg_iface;
 
     /**************************************************************************
      * Attributes
@@ -163,11 +198,19 @@ private:
     std::vector<property_t<std::string>> _prop_type_out;
     std::vector<property_t<int>> _prop_max_num_coeffs;
 
-    /**************************************************************************
-     * Register interface
-     *************************************************************************/
-    multichan_register_iface _fir_filter_reg_iface;
+    //! Maximum number of coefficients supported by the FIR filter
+    std::vector<size_t> _max_num_coeffs;
+
+    //! Current fir filter coefficients
+    std::vector<std::vector<int16_t>> _coeffs;
+
+    //! Compat number
+    const uhd::compat_num32 _compat;
+
+    //! Direction of coefficient loading
+    const bool _coeff_load_backwards;
 };
 
+static std::vector<noc_id_t> FIR_NOC_IDS{FIR_FILTER_BLOCK, FIR_FILTER_BLOCK_V2};
 UHD_RFNOC_BLOCK_REGISTER_DIRECT(
-    fir_filter_block_control, FIR_FILTER_BLOCK, "FIR", CLOCK_KEY_GRAPH, "bus_clk")
+    fir_filter_block_control, FIR_NOC_IDS, "FIR", CLOCK_KEY_GRAPH, "bus_clk")
