@@ -17,12 +17,6 @@
 
 using namespace uhd::rfnoc;
 
-namespace {
-
-const std::string DEFAULT_GAIN_PROFILE("default");
-
-} // namespace
-
 const std::string radio_control::ALL_LOS   = "all";
 const std::string radio_control::ALL_GAINS = "";
 
@@ -109,6 +103,24 @@ radio_control_impl::radio_control_impl(make_args_ptr make_args)
             }
             post_action({res_source_info::OUTPUT_EDGE, port}, stream_cmd_action);
         });
+
+    register_action_handler(ACTION_KEY_TUNE_REQUEST,
+        [this](const res_source_info& src, action_info::sptr action) {
+            tune_request_action_info::sptr tune_request_action =
+                std::dynamic_pointer_cast<tune_request_action_info>(action);
+
+            if (!tune_request_action) {
+                RFNOC_LOG_WARNING("Received invalid Tune request command!");
+                return;
+            }
+            const size_t port = src.instance;
+            if (port >= get_num_output_ports()) {
+                RFNOC_LOG_WARNING("Received tune_request to invalid output port!");
+                return;
+            }
+            _tune_request_action_handler(tune_request_action, src);
+        });
+
     // Register spp properties and resolvers
     _spp_prop.reserve(get_num_output_ports());
     _atomic_item_size_in.reserve(get_num_input_ports());
@@ -193,7 +205,7 @@ radio_control_impl::radio_control_impl(make_args_ptr make_args)
                 RFNOC_LOG_TRACE("Calling resolver for spp@" << chan);
                 const size_t max_pyld =
                     get_max_payload_size({res_source_info::OUTPUT_EDGE, chan});
-                const int max_spp = get_max_spp(max_pyld);
+                const int max_spp = get_max_spp(max_pyld - max_pyld % ais_out.get());
                 if (spp.get() > max_spp) {
                     RFNOC_LOG_DEBUG("spp value "
                                     << spp.get() << " exceeds MTU of "
@@ -235,7 +247,8 @@ radio_control_impl::radio_control_impl(make_args_ptr make_args)
                 chan,
                 &samp_rate_in  = _samp_rate_in.at(chan),
                 &samp_rate_out = _samp_rate_out.at(chan)]() {
-                RFNOC_LOG_TRACE("Calling resolver for samp_rate@" << chan);
+                UHD_LOGGER_TRACE(this->get_unique_id())
+                    << "Calling resolver for samp_rate@" << chan;
                 samp_rate_in  = coerce_rate(samp_rate_in.get());
                 samp_rate_out = samp_rate_in.get();
             });
@@ -719,6 +732,86 @@ uhd::meta_range_t radio_control_impl::get_tx_power_range(const size_t chan)
     return _tx_pwr_mgr.at(chan)->get_power_range();
 }
 
+static uhd::meta_range_t make_overall_tune_range(const uhd::meta_range_t& fe_range,
+    const uhd::meta_range_t& dsp_range,
+    const double bw)
+{
+    uhd::meta_range_t range;
+    for (const uhd::range_t& sub_range : fe_range) {
+        range.push_back(uhd::range_t(
+            std::max(0.0, sub_range.start() + std::max(dsp_range.start(), -bw / 2)),
+            sub_range.stop() + std::min(dsp_range.stop(), bw / 2),
+            dsp_range.step()));
+    }
+    return range;
+}
+
+void radio_control_impl::apply_and_update_tune_request(
+    tune_request_action_info::sptr tune_request_action,
+    std::function<void(double)> set_rf_freq,
+    std::function<double()> get_rf_freq)
+{
+    uhd::tune_request_t tune_request = tune_request_action->tune_request;
+    const double clipped_requested_freq =
+        tune_request_action->overall_freq_range.clip(tune_request.target_freq);
+
+    RFNOC_LOG_TRACE(str(boost::format("Frequency Range %.3fMHz->%.3fMHz")
+                        % (tune_request_action->overall_freq_range.start() / 1e6)
+                        % (tune_request_action->overall_freq_range.stop() / 1e6)));
+
+    RFNOC_LOG_TRACE(str(boost::format("Clipped frequency requested: %.3fMHz")
+                        % (clipped_requested_freq / 1e6)));
+
+    //------------------------------------------------------------------
+    //-- set the RF frequency depending upon the policy
+    //------------------------------------------------------------------
+    double target_rf_freq = 0.0;
+    switch (tune_request.rf_freq_policy) {
+        case uhd::tune_request_t::POLICY_AUTO:
+            target_rf_freq = clipped_requested_freq;
+            break;
+
+        case uhd::tune_request_t::POLICY_MANUAL:
+            if ((tune_request.dsp_freq_policy == uhd::tune_request_t::POLICY_AUTO)
+                && (tune_request_action->dsp_range.size() == 1)
+                && tune_request_action->dsp_range.stop() == 0) {
+                /* Hardware does not incl. DSP chain
+                 * (dsp_freq_range only has single item, with value 0),
+                 * requested dsp frequency will be combined with rf frequency.
+                 * The case to handle uses MANUAL rf_freq_policy and
+                 * AUTOMATIC dsp_freq_policy */
+                RFNOC_LOG_DEBUG(
+                    str(boost::format("No DSP capabilities detected. Combining offset "
+                                      "into target frequency of %.3fMHz")
+                        % (clipped_requested_freq / 1e6)));
+
+                target_rf_freq = clipped_requested_freq;
+            } else {
+                /* Normal manual mode observing individual tune requests*/
+                target_rf_freq = tune_request_action->rf_range.clip(tune_request.rf_freq);
+            }
+
+        case uhd::tune_request_t::POLICY_NONE:
+            break;
+    }
+    RFNOC_LOG_TRACE(
+        str(boost::format("Target RF Freq: %.3fMHz") % (target_rf_freq / 1e6)));
+
+    //------------------------------------------------------------------
+    //-- Tune the RF frontend
+    //------------------------------------------------------------------
+    if (tune_request.rf_freq_policy != uhd::tune_request_t::POLICY_NONE) {
+        set_rf_freq(target_rf_freq);
+    }
+    const double actual_rf_freq = get_rf_freq();
+
+    RFNOC_LOG_TRACE(
+        str(boost::format("RADIO Actual RF Freq: %.3fMHz") % (actual_rf_freq / 1e6)));
+
+    tune_request_action->tune_result.clipped_rf_freq = clipped_requested_freq;
+    tune_request_action->tune_result.target_rf_freq  = target_rf_freq;
+    tune_request_action->tune_result.actual_rf_freq  = actual_rf_freq;
+}
 
 /******************************************************************************
  * LO Default API
@@ -998,6 +1091,67 @@ void radio_control_impl::enable_rx_timestamps(const bool enable, const size_t ch
     _radio_reg_iface.poke32(regmap::REG_RX_HAS_TIME, enable ? 0x1 : 0x0, chan);
 }
 
+/****************************************************************************
+ * Tune Request API
+ ***************************************************************************/
+void radio_control_impl::_tune_request_action_handler(
+    tune_request_action_info::sptr tune_request_action, const res_source_info& src)
+{
+    RFNOC_LOG_TRACE("Received tune request on " << src.to_string());
+
+    res_source_info dst_edge{res_source_info::invert_edge(src.type), src.instance};
+    const size_t chan = src.instance;
+    freq_range_t tune_range_nonmono;
+    uhd::tune_request_t tune_request = tune_request_action->tune_request;
+
+    if (src.type == res_source_info::OUTPUT_EDGE) {
+        set_rx_tune_args(tune_request.args, chan);
+
+        tune_range_nonmono = (tune_request_action->dsp_range.empty())
+                                 ? get_rx_frequency_range(chan)
+                                 : make_overall_tune_range(get_rx_frequency_range(chan),
+                                     tune_request_action->dsp_range,
+                                     get_rx_bandwidth(chan));
+
+        tune_request_action->overall_freq_range = tune_range_nonmono.as_monotonic();
+        tune_request_action->rf_range           = get_rx_frequency_range(chan);
+
+        auto set_rf_freq = [this, chan](double freq) { set_rx_frequency(freq, chan); };
+        auto get_rf_freq = [this, chan]() { return get_rx_frequency(chan); };
+
+        apply_and_update_tune_request(tune_request_action, set_rf_freq, get_rf_freq);
+
+    } else if (src.type == res_source_info::INPUT_EDGE) {
+        set_tx_tune_args(tune_request.args, chan);
+
+        tune_range_nonmono = (tune_request_action->dsp_range.empty())
+                                 ? get_tx_frequency_range(chan)
+                                 : make_overall_tune_range(get_tx_frequency_range(chan),
+                                     tune_request_action->dsp_range,
+                                     get_tx_bandwidth(chan));
+
+        tune_request_action->overall_freq_range = tune_range_nonmono.as_monotonic();
+        tune_request_action->rf_range           = get_tx_frequency_range(chan);
+
+        auto set_rf_freq = [this, chan](double freq) { set_tx_frequency(freq, chan); };
+        auto get_rf_freq = [this, chan]() { return get_tx_frequency(chan); };
+
+        apply_and_update_tune_request(tune_request_action, set_rf_freq, get_rf_freq);
+    }
+
+    RFNOC_LOG_TRACE(
+        "Tune_result details radio_control.cpp : target_rf_frq = "
+        << tune_request_action->tune_result.target_rf_freq
+        << " target dsp freq = " << tune_request_action->tune_result.target_dsp_freq
+        << " clipped rf_freq " << tune_request_action->tune_result.clipped_rf_freq
+        << " actual_rf_freq = " << tune_request_action->tune_result.actual_rf_freq
+        << " actual dsp_freq= " << tune_request_action->tune_result.actual_dsp_freq);
+
+    RFNOC_LOG_TRACE("Sending tune_request to " << src.to_string()
+                                               << ", id==" << tune_request_action->id);
+    post_action(src, tune_request_action);
+}
+
 /******************************************************************************
  * Private methods
  *****************************************************************************/
