@@ -161,6 +161,16 @@ public:
                 }
                 _handle_tx_event_action(src, tx_event_action);
             });
+        register_action_handler(ACTION_KEY_TUNE_REQUEST,
+            [this](const res_source_info& src, action_info::sptr action) {
+                tune_request_action_info::sptr tune_request_action =
+                    std::dynamic_pointer_cast<tune_request_action_info>(action);
+                if (!tune_request_action) {
+                    RFNOC_LOG_WARNING("Received invalid tune request action!");
+                    return;
+                }
+                RFNOC_LOG_DEBUG("Received tune request on " << src.to_string());
+            });
 
         // Initialize record properties
         _record_type.reserve(_num_input_ports);
@@ -462,6 +472,26 @@ public:
         }
     }
 
+    void post_input_action(const std::shared_ptr<uhd::rfnoc::action_info>& action,
+        const size_t port) override
+    {
+        if (port > get_num_input_ports()) {
+            throw uhd::runtime_error("Invalid port. Please provide a valid port");
+        }
+        const uhd::rfnoc::res_source_info info(res_source_info::INPUT_EDGE, port);
+        post_action(info, action);
+    }
+
+    void post_output_action(const std::shared_ptr<uhd::rfnoc::action_info>& action,
+        const size_t port) override
+    {
+        if (port > get_num_output_ports()) {
+            throw uhd::runtime_error("Invalid port. Please provide a valid port");
+        }
+        const uhd::rfnoc::res_source_info info(res_source_info::OUTPUT_EDGE, port);
+        post_action(info, action);
+    }
+
 protected:
     // Block-specific register interface
     multichan_register_iface _replay_reg_iface;
