@@ -96,7 +96,7 @@ public:
         // Extract buff and sanity check
         const size_t nbytes = boost::asio::buffer_size(user_buff);
         UHD_ASSERT_THROW(nbytes <= _link->get_send_frame_size())
-        const uint8_t* user_data = boost::asio::buffer_cast<const uint8_t*>(user_buff);
+        const uint8_t* user_data = static_cast<const uint8_t*>(user_buff.data());
 
         // Get send buff
         auto buff = _send_io->get_send_buff(SEND_TIMEOUT_MS);
@@ -120,7 +120,7 @@ public:
     size_t recv(const boost::asio::mutable_buffer& user_buff, double timeout) override
     {
         size_t user_buff_size = boost::asio::buffer_size(user_buff);
-        uint8_t* user_data    = boost::asio::buffer_cast<uint8_t*>(user_buff);
+        uint8_t* user_data    = static_cast<uint8_t*>(user_buff.data());
 
         auto buff = _recv_io->get_recv_buff(static_cast<int32_t>(timeout * 1e3));
         if (!buff) {
