@@ -657,8 +657,7 @@ public:
         }
     }
 
-    const std::string get_rx_lo_source(
-        const std::string& name, const size_t chan) override
+    std::string get_rx_lo_source(const std::string& name, const size_t chan) override
     {
         fs_path rx_fe_fe_root = get_db_path("rx", chan);
 
@@ -1527,6 +1526,14 @@ private:
                     _basic_lf_tx         = true;
                     break;
             }
+// If we take all supported versions of clang, gcc, and MSVC, we get some versions
+// that require lambda captures for constexpr, and some compilers throw a warnings
+// when you use a lambdas capture.
+// To make everyone "happy", we turn off those warnings for clang.
+#pragma GCC diagnostic push
+#ifdef __clang__
+#    pragma GCC diagnostic ignored "-Wunused-lambda-capture"
+#endif
             // Add to tree
             get_tree()
                 ->create<dboard_eeprom_t>(DB_PATH / EEPROM_PATHS[i])
@@ -1535,15 +1542,23 @@ private:
                                             const uhd::usrp::dboard_eeprom_t& db_eeprom) {
                     _set_db_eeprom(zpu_i2c, BASE_ADDR | addr, db_eeprom);
                 });
+#pragma GCC diagnostic pop
         }
 
         // create a new dboard interface
         x300_dboard_iface_config_t db_config;
-        db_config.gpio           = gpio_atr::db_gpio_atr_3000::make(_wb_iface,
+        db_config.gpio = gpio_atr::db_gpio_atr_3000::make(_wb_iface,
             gpio_atr::gpio_atr_offsets::make_default(x300_regs::SR_DB_GPIO,
                 x300_regs::RB_DB_GPIO,
                 x300_regs::PERIPH_REG_OFFSET));
-        db_config.spi            = _spi;
+        db_config.spi  = _spi;
+        db_config.define_custom_register_space =
+            [this](uint32_t start_addr,
+                uint32_t length,
+                std::function<void(uint32_t, uint32_t)> poke_fn,
+                std::function<uint32_t(uint32_t)> peek_fn) {
+                regs().define_custom_register_space(start_addr, length, poke_fn, peek_fn);
+            };
         db_config.rx_spi_slaveno = DB_RX_SEN;
         db_config.tx_spi_slaveno = DB_TX_SEN;
         db_config.i2c            = zpu_i2c;
