@@ -19,6 +19,7 @@
 #include <uhd/utils/log.hpp>
 #include <uhd/utils/paths.hpp>
 #include <uhd/utils/static.hpp>
+#include <uhdlib/utils/paths.hpp>
 #include <stdint.h>
 #include <boost/asio.hpp>
 #include <boost/assign.hpp>
@@ -264,10 +265,13 @@ octoclock_impl::octoclock_impl(const device_addr_t& _device_addr)
         // Set up EEPROM
         ////////////////////////////////////////////////////////////////////
         _oc_dict[oc].eeprom = octoclock_eeprom_t(_oc_dict[oc].ctrl_xport, _proto_ver);
-        _tree->create<octoclock_eeprom_t>(oc_path / "eeprom")
+        _tree->create<uhd::usrp::mboard_eeprom_t>(oc_path / "eeprom")
             .set(_oc_dict[oc].eeprom)
             .add_coerced_subscriber(
-                std::bind(&octoclock_impl::_set_eeprom, this, oc, std::placeholders::_1));
+                std::bind(&octoclock_impl::_set_eeprom, this, oc, std::placeholders::_1))
+            .set_publisher([this, oc]() {
+                return static_cast<uhd::usrp::mboard_eeprom_t>(this->_oc_dict[oc].eeprom);
+            });
 
         ////////////////////////////////////////////////////////////////////
         // Initialize non-GPSDO sensors
@@ -489,8 +493,7 @@ std::string octoclock_impl::_get_images_help_message(const std::string& addr)
 #endif
 
     // Get burner command
-    const std::string burner_path =
-        (fs::path(uhd::get_pkg_path()) / "bin" / "uhd_image_loader").string();
+    const std::string burner_path = uhd::find_uhd_command("uhd_image_loader");
     const std::string burner_cmd =
         str(boost::format("%s %s--addr=\"%s\"") % burner_path % ml % addr);
     return str(boost::format("%s\n%s")
