@@ -9,6 +9,8 @@
 
 #ifdef BOOST_MSVC
 #    include <windows.h>
+#elif defined(__OpenBSD__)
+#    include <glob.h>
 #else
 #    include <wordexp.h>
 #endif
@@ -27,6 +29,17 @@ std::string uhd::path_expandvars(const std::string& path)
         return path;
     }
     return std::string(result, result + result_len);
+#elif defined(__OpenBSD__)
+    glob_t p;
+    std::string return_value;
+    memset(&p, 0, sizeof(p));
+    if (glob(path.c_str(), GLOB_TILDE, NULL, &p) == 0 && p.gl_pathc > 0) {
+        return_value = std::string(p.gl_pathv[0]);
+    } else {
+        return_value = path;
+    }
+    globfree(&p);
+    return return_value;
 #else
     wordexp_t p;
     std::string return_value;
