@@ -196,6 +196,11 @@ public:
     }
 
     void issue_stream_cmd(const stream_cmd_t& /*stream_cmd*/) override {}
+
+    void post_input_action(
+        const std::shared_ptr<uhd::rfnoc::action_info>&, const size_t) override
+    {
+    }
 };
 
 /*!
@@ -230,6 +235,11 @@ public:
     {
         return false;
     }
+
+    void post_output_action(
+        const std::shared_ptr<uhd::rfnoc::action_info>&, const size_t) override
+    {
+    }
 };
 
 using rx_streamer_mock_xport = mock_rx_streamer<mock_rx_data_xport>;
